@@ -1,4 +1,4 @@
-from .ac_controller import AcController
+from .ac_controller import BroadlinkAcController
 from .broadlink_controller import BroadlinkDeviceController
 from .broadlink_rgb_lamp_controller import BroadlinkRgbLampController
-from .tv_controller import TvController
+from .tv_controller import BroadlinkTvController
